<?php

namespace Litecms\Broker\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Broker\Models\Broker;

class BrokerPolicy
{

    /**
     * Determine if the given user can view the broker.
     *
     * @param UserPolicy $user
     * @param Broker $broker
     *
     * @return bool
     */
    public function view(UserPolicy $user, Broker $broker)
    {
        if ($user->canDo('broker.broker.view') && $user->isAdmin()) {
            return true;
        }

        return $broker->user_id == user_id() && $broker->user_type == user_type();
    }

    /**
     * Determine if the given user can create a broker.
     *
     * @param UserPolicy $user
     * @param Broker $broker
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('broker.broker.create');
    }

    /**
     * Determine if the given user can update the given broker.
     *
     * @param UserPolicy $user
     * @param Broker $broker
     *
     * @return bool
     */
    public function update(UserPolicy $user, Broker $broker)
    {
        if ($user->canDo('broker.broker.edit') && $user->isAdmin()) {
            return true;
        }

        return $broker->user_id == user_id() && $broker->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given broker.
     *
     * @param UserPolicy $user
     * @param Broker $broker
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Broker $broker)
    {
        return $broker->user_id == user_id() && $broker->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given broker.
     *
     * @param UserPolicy $user
     * @param Broker $broker
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Broker $broker)
    {
        if ($user->canDo('broker.broker.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given broker.
     *
     * @param UserPolicy $user
     * @param Broker $broker
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Broker $broker)
    {
        if ($user->canDo('broker.broker.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
